__init__ — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# __init__

KPath.__init__(knames=None, kticks=None, special_kpoints=None, ngrids=None, has_time_reversal=True)

  The Kpath object to handle labels and ticks for band structure

  Parameters:

    - knames (List, optional) – List of Knames, by default None

    - kticks (List, optional) – List of kticks that maps the knames to the kpoints, by default None

    - special_kpoints (List, optional) – List of special kpoints, by default None

    - ngrids (List, optional) – List of how many points are between special kpoints, by default None

    - has_time_reversal (bool, optional) – Determine if the kpoints contain time reversal symmetry, by default True